import '../tool/inject.dart';

/// Enumeration to identify if the app is running using a
/// development environment or a production one
enum SWEnvironment { DEV, PROD, HOM }

SWEnvironment get _env => get<SWEnvironment>();

extension SWEnv on SWEnvironment {
  bool get isDev => _env == SWEnvironment.DEV;

  bool get isProd => _env == SWEnvironment.PROD;

  bool get isHom => _env == SWEnvironment.HOM;

  void onEnvironment(
    Function onDev,
    Function onProd,
    Function onHom,
  ) {
    switch (_env) {
      case SWEnvironment.DEV:
        onDev.call();
        break;
      case SWEnvironment.PROD:
        onProd.call();
        break;
      case SWEnvironment.HOM:
        onHom.call();
        break;
    }
  }
}
